Documentation
¶
Index ¶
Constants ¶
Variables ¶
This section is empty.
Functions ¶
func GeohashEncode ¶
func GetDistance ¶
GetDistance returns distance in meters between 2 given points
func GetTotalDistance ¶
GetTotalDistance returns total distance in meters for between points in a list
Types ¶
type BBox ¶
type BBox struct {
// contains filtered or unexported fields
}
func GetBoundingBox ¶
GetBoundingBox returns a bounding box for a point and certain distance in meters
type GeohashDecoded ¶
type GeohashDecoded struct {
// contains filtered or unexported fields
}
func GeohashDecode ¶
func GeohashDecode(hash string) (*GeohashDecoded, error)
func (*GeohashDecoded) Lat ¶
func (ghd *GeohashDecoded) Lat() float64
func (*GeohashDecoded) LatErr ¶
func (ghd *GeohashDecoded) LatErr() float64
func (*GeohashDecoded) Lng ¶
func (ghd *GeohashDecoded) Lng() float64
func (*GeohashDecoded) LngErr ¶
func (ghd *GeohashDecoded) LngErr() float64
type LatLng ¶
type LatLng struct {
// contains filtered or unexported fields
}
func GetMidPoint ¶
GetMidPoint returns center point calculated based on a list of points
func GetPointByBearing ¶
GetPointByBearing returns a point calculated based on a given point, bearing and travelling distance lat, lng given in decimal degrees, bearing is given in degrees and distance is in meters
Click to show internal directories.
Click to hide internal directories.